@@ -8,10 +8,11 @@ except:
     from .basic_search_engine_spider import EngineBaseSpdier 
 from utils.proxies import sign, auth, proxy
 from models.result import SearchItem
-from typing import List
+from typing import List, Optional, Union
 from lxml.etree import HTML
 from urllib import response
 import requests
+from requests import Response
 from pprint import pprint
 from loguru import logger
 from queue import Queue
@@ -100,13 +101,18 @@ class BingSpider():
             for page_num in range(start_page, end_page + 1):
                 self.params_queue.put((keyword, page_num))
 
-    def single_request(self, keyword: str, page_num=0, **kwargs):
-        """请求一个关键词的一页数据
+    def single_request(self, keyword: str, page_num=0, proxies:Dict =None, **kwargs) -> requests.Response:
+        """
+        请求一个关键词的一页数据
 
         Args:
             keyword (_type_): 关键词
             page_num (int, optional): 页数. Defaults to 0.
             item_num (int, optional): . Defaults to 0.
+        
+        Returns:
+            requests.Response: 返回的response
+        
         """
         # 参数处理
         self.params["q"] = keyword
@@ -115,8 +121,7 @@ class BingSpider():
         self.params['jsoncbid'] = str(page_num)
         # 请求
         try:
-            if kwargs.get("proxies"):
-                proxies = kwargs.get("proxies")
+            if proxies:
                 try:
                     response = requests.get(
                         url=self.url, headers=self.headers, params=self.params, timeout=10, proxies=proxies, verify=False, allow_redirects=False)
@@ -146,8 +151,13 @@ class BingSpider():
             else:
                 return True
 
-    def parser(self, response, **kwargs):
-        # 解析
+    def parser(self, response, **kwargs) -> List[Dict]:
+        """
+        解析一个bing搜索返回的response 
+
+        :param requests.Response response: 一个bing搜索返回的response
+        :return List[Dict]: 返回一个列表，列表中每个元素是一个字典，字典中包含title, link, content, date
+        """
         doc = HTML(response.text)
         items = doc.xpath('//li[@class="b_algo"]')
         page_num = kwargs.get("page_num") if kwargs.get("page_num") else 0
@@ -210,19 +220,27 @@ class BingSpider():
     #         self.saver(item)
         # time.sleep(1)
 
-    def search(self, keyword, start_page: int = 0, end_page: int = 1, item_num: int = None, **kwargs):
+    def search(self, keyword, start_page: int = 0, end_page: int = 1, item_num: int = 0, proxies=None, callback=None, **kwargs):
         """
-        传入一个关键词，返回一个item list
-        @keyword: 关键词
-        @start_page: 开始页
-        @end_page: 结束页
-        @item_num: 返回item数，写1就拿一个。比如我是0，10页，每页100个，但是item写1，就只返回一个。
-        @kwargs: 其他参数，如代理包括proxies, auth
+        搜索给定关键词并返回结果列表。
+
+        :param keyword: str, 搜索的关键词。
+        :param start_page: int, 开始页码（包含），默认为1。
+        :param end_page: int, 结束页码（包含）。
+        :param item_num: int, 返回每页的结果数，例如，如果item_num为1，则每页仅返回1个结果。默认为10。
+        :param kwargs: dict, 其他参数，如代理（proxies）和认证（auth）信息。
+        :return: List[Dict], 包含搜索结果的列表，每个结果是一个字典。
+
+        Example:
+        带代理的
+        kwargs = {
+            
+        }
+        self.search("chatgpt", **kwargs)
         """
         all_item_list = []
         # 若获取代理不为None或不为空字典则启用代理，允许传入空字典，则不启用代理
-        if kwargs.get('proxies') != None and kwargs.get('proxies') != {}:
-            proxies = kwargs.get("proxies") if kwargs.get("proxies") else None
+        if proxies != None:
             auth = kwargs.get("auth") if kwargs.get("auth") else None
             self.headers.update({
                 "Proxy-Authorization": auth,
@@ -248,10 +266,13 @@ class BingSpider():
                 else:
                     logger.error("response is invalid")
                     continue
+        # 回调
+        if callback:
+            callback(all_item_list)
 
         # 处理
         # item_list = self.parser(response, **{"keyword": keyword, "page_num": start_page, "item_num": item_num})
-        if item_num:
+        if item_num != 0:
             logger.info(f"【{keyword}】根据item num返回{item_num}个")
             return all_item_list[item_num:]
         else:
@@ -307,13 +328,16 @@ class BingNewsSpider(EngineBaseSpdier):
             "PCW": "1116"
         }
 
-    def request(self, keyword: str, page_num: int = 0, proxies: Optional[Dict] = {}, cookies: Optional[Dict] = {}, **kwargs):
+    def _request(self, keyword: str, page_num: int = 0, proxies: Optional[Dict] = {}, cookies: Optional[Dict] = {}, **kwargs) -> Response:
         """
-        @summary:单次请求
-        ---------
-        @param url: 请求url
-        --------
-        @result: request, response
+        请求news接口单页数据, 返回Response对象
+
+        :param str keyword: 关键词
+        :param int page_num: 请求第几页, defaults to 0
+        :param Optional[Dict] proxies: 代理信息, defaults to {}
+        :param Optional[Dict] cookies: cookies信息, defaults to {}
+        :raises e: _description_
+        :return Reponse: request response对象
         """
         # 参数处理
         self.params["q"] = keyword
@@ -343,7 +367,13 @@ class BingNewsSpider(EngineBaseSpdier):
             raise e
         return response
 
-    def parser(self, response, **kwargs):
+    def parser(self, response, **kwargs) -> List[Dict]:
+        """
+        解析response, 返回item_list
+
+        :param _type_ response: _description_
+        :return _type_: _description_
+        """
         item_list = []
         doc = HTML(response.text)
         res = doc.xpath('//div[contains(@class,"news-card")]')
@@ -394,17 +424,17 @@ class BingNewsSpider(EngineBaseSpdier):
             if proxy == {} or proxy == None:
                 if kwargs.get('cookie') != None and kwargs.get('cookie') != {}:
                     cookie = kwargs.get("cookie")
-                    response = self.request(keyword, i, cookies=cookie)
+                    response = self._request(keyword, i, cookies=cookie)
                 else:
-                    response = self.request(keyword, i)
+                    response = self._request(keyword, i)
             # 有代理
             else:
                 if kwargs.get('cookie') != None and kwargs.get('cookie') != {}:
                     cookie = kwargs.get("cookie")
-                    response = self.request(
+                    response = self._request(
                         keyword, i, proxies=proxy, cookies=cookie)
                 else:
-                    response = self.request(keyword, i, proxies=proxy)
+                    response = self._request(keyword, i, proxies=proxy)
 
             # 解析
             search_item_list = self.parser(
